==> restful-1.50.5-sources.jar: com/aote/util/other/JwtTools.java <==
package com.aote.util.other;

import io.jsonwebtoken.Claims;
import io.jsonwebtoken.SignatureAlgorithm;

import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;
import javax.xml.bind.DatatypeConverter;
import java.util.Collection;
import java.util.Date;
import java.util.Map;
import java.util.Set;

/**
 * 操作Jwt的工具类
 */
public class JwtTools {
    //保存在服务端的密钥,
    private static final String SECRET = "xxfxxfxxfxxfxxf";
    //jwt令牌的有效时间
    private static final int EXPSECOND= 60*60*5*1000;

    //生成密钥
    private  SecretKey getKey(){
        //HS256加密方式加密
        SignatureAlgorithm signatureAlgorithm = SignatureAlgorithm.HS256;
        //密钥
        byte[]  apiKeySecretBytes = DatatypeConverter.parseBase64Binary(SECRET);
        SecretKey signingKey = new SecretKeySpec(apiKeySecretBytes,signatureAlgorithm.getJcaName());
        return signingKey;
    }

    //生成用户令牌Token 返回到客户端 便于下次登陆使用
    public  String UserToken(String userid,String username,String password){
        return userid;
        //生成Token
      /*  JwtBuilder jb = Jwts.builder().setHeaderParam("typ","JWT")
                .claim("userid",userid)
                .claim("username",username)
                .claim("password",password)
                .signWith(SignatureAlgorithm.HS256,getKey());*/
        //设置令牌过期时间
       /* if(EXPSECOND>=0){
            //当前时间
            Long now = System.currentTimeMillis();
            Long expMills = now+EXPSECOND;
            Date expDate = new Date(expMills);
            System.out.println("令牌的到期时间:"+expDate);
            jb.setExpiration(expDate).setNotBefore(new Date());
        }
        String UserToken = jb.compact();
        String sign = UserToken.split("\\.")[2];
        return UserToken;*/
    }
    //解密jwt
    public  Claims parseJWT(String UserToken) throws Exception {
        Claims claims = new Claims() {
            @Override
            public String getIssuer() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Claims setIssuer(String iss) {
                throw new UnsupportedOperationException();
            }

            @Override
            public String getSubject() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Claims setSubject(String sub) {
                throw new UnsupportedOperationException();
            }

            @Override
            public String getAudience() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Claims setAudience(String aud) {
                throw new UnsupportedOperationException();
            }

            @Override
            public Date getExpiration() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Claims setExpiration(Date exp) {
                throw new UnsupportedOperationException();
            }

            @Override
            public Date getNotBefore() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Claims setNotBefore(Date nbf) {
                throw new UnsupportedOperationException();
            }

            @Override
            public Date getIssuedAt() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Claims setIssuedAt(Date iat) {
                throw new UnsupportedOperationException();
            }

            @Override
            public String getId() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Claims setId(String jti) {
                throw new UnsupportedOperationException();
            }

            @Override
            public <T> T get(String claimName, Class<T> requiredType) {
                throw new UnsupportedOperationException();
            }

            @Override
            public int size() {
                throw new UnsupportedOperationException();
            }

            @Override
            public boolean isEmpty() {
                throw new UnsupportedOperationException();
            }

            @Override
            public boolean containsKey(Object key) {
                throw new UnsupportedOperationException();
            }

            @Override
            public boolean containsValue(Object value) {
                throw new UnsupportedOperationException();
            }

            @Override
            public Object get(Object key) {
                return UserToken;
            }

            @Override
            public Object put(String key, Object value) {
                throw new UnsupportedOperationException();
            }

            @Override
            public Object remove(Object key) {
                throw new UnsupportedOperationException();
            }

            @Override
            public void putAll(Map<? extends String, ?> m) {
                throw new UnsupportedOperationException();
            }

            @Override
            public void clear() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Set<String> keySet() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Collection<Object> values() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Set<Entry<String, Object>> entrySet() {
                throw new UnsupportedOperationException();
            }
        };

        return claims;

        /*  SecretKey key = getKey();  //签名秘钥，和生成的签名的秘钥一模一样
        Claims claims = Jwts.parser()  //得到DefaultJwtParser
                .setSigningKey(key)                 //设置签名的秘钥
                .parseClaimsJws(UserToken).getBody();     //设置需要解析的jwt
        return claims;*/
    }

}

==> restful-1.54.6-sources.jar: com/aote/util/other/JwtTools.java <==
package com.aote.util.other;

import io.jsonwebtoken.Claims;
import io.jsonwebtoken.SignatureAlgorithm;

import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;
import javax.xml.bind.DatatypeConverter;
import java.util.Collection;
import java.util.Date;
import java.util.Map;
import java.util.Set;

/**
 * 操作Jwt的工具类
 */
public class JwtTools {
    //保存在服务端的密钥,
    private static final String SECRET = "xxfxxfxxfxxfxxf";
    //jwt令牌的有效时间
    private static final int EXPSECOND= 60*60*5*1000;

    //生成密钥
    private  SecretKey getKey(){
        //HS256加密方式加密
        SignatureAlgorithm signatureAlgorithm = SignatureAlgorithm.HS256;
        //密钥
        byte[]  apiKeySecretBytes = DatatypeConverter.parseBase64Binary(SECRET);
        return new SecretKeySpec(apiKeySecretBytes,signatureAlgorithm.getJcaName());
    }

    //生成用户令牌Token 返回到客户端 便于下次登陆使用
    public  String UserToken(String userid,String username,String password){
        return userid;
        //生成Token
      /*  JwtBuilder jb = Jwts.builder().setHeaderParam("typ","JWT")
                .claim("userid",userid)
                .claim("username",username)
                .claim("password",password)
                .signWith(SignatureAlgorithm.HS256,getKey());*/
        //设置令牌过期时间
       /* if(EXPSECOND>=0){
            //当前时间
            Long now = System.currentTimeMillis();
            Long expMills = now+EXPSECOND;
            Date expDate = new Date(expMills);
            System.out.println("令牌的到期时间:"+expDate);
            jb.setExpiration(expDate).setNotBefore(new Date());
        }
        String UserToken = jb.compact();
        String sign = UserToken.split("\\.")[2];
        return UserToken;*/
    }
    //解密jwt
    public  Claims parseJWT(String UserToken) {

        return new Claims() {
            @Override
            public String getIssuer() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Claims setIssuer(String iss) {
                throw new UnsupportedOperationException();
            }

            @Override
            public String getSubject() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Claims setSubject(String sub) {
                throw new UnsupportedOperationException();
            }

            @Override
            public String getAudience() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Claims setAudience(String aud) {
                throw new UnsupportedOperationException();
            }

            @Override
            public Date getExpiration() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Claims setExpiration(Date exp) {
                throw new UnsupportedOperationException();
            }

            @Override
            public Date getNotBefore() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Claims setNotBefore(Date nbf) {
                throw new UnsupportedOperationException();
            }

            @Override
            public Date getIssuedAt() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Claims setIssuedAt(Date iat) {
                throw new UnsupportedOperationException();
            }

            @Override
            public String getId() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Claims setId(String jti) {
                throw new UnsupportedOperationException();
            }

            @Override
            public <T> T get(String claimName, Class<T> requiredType) {
                throw new UnsupportedOperationException();
            }

            @Override
            public int size() {
                throw new UnsupportedOperationException();
            }

            @Override
            public boolean isEmpty() {
                throw new UnsupportedOperationException();
            }

            @Override
            public boolean containsKey(Object key) {
                throw new UnsupportedOperationException();
            }

            @Override
            public boolean containsValue(Object value) {
                throw new UnsupportedOperationException();
            }

            @Override
            public Object get(Object key) {
                return UserToken;
            }

            @Override
            public Object put(String key, Object value) {
                throw new UnsupportedOperationException();
            }

            @Override
            public Object remove(Object key) {
                throw new UnsupportedOperationException();
            }

            @Override
            public void putAll(Map<? extends String, ?> m) {
                throw new UnsupportedOperationException();
            }

            @Override
            public void clear() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Set<String> keySet() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Collection<Object> values() {
                throw new UnsupportedOperationException();
            }

            @Override
            public Set<Entry<String, Object>> entrySet() {
                throw new UnsupportedOperationException();
            }
        };

        /*  SecretKey key = getKey();  //签名秘钥，和生成的签名的秘钥一模一样
        Claims claims = Jwts.parser()  //得到DefaultJwtParser
                .setSigningKey(key)                 //设置签名的秘钥
                .parseClaimsJws(UserToken).getBody();     //设置需要解析的jwt
        return claims;*/
    }

}
